.. meta::
   :description: Tutorials for getting started with MAITE.

.. _tutorials:

Tutorials
=========

Tutorials are meant to acquaint you with all of the essential functionality of the 
MAITE library. They require no prior experience with these tools.

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   tutorials/torchvision_object_detection


Tutorials only focus on practical steps towards concrete outcomes, 
and thus they do not explain how MAITE works. To gain a deeper 
understanding of the technical details here, please refer to the 
:ref:`maite-reference`.
